@@ -36,6 +36,9 @@ var scanCmd = &cobra.Command{
 Detect compliance and security violations across Infrastructure as Code to mitigate risk before provisioning cloud native infrastructure.
 `,
 	PreRunE: func(cmd *cobra.Command, args []string) error {
+		if scanOptions.configOnly {
+			return nil
+		}
 		return initial(cmd, args, true)
 	},
 	RunE:          scan,
