@@ -17,6 +17,7 @@
 package commons
 
 import (
+	"encoding/json"
 	"io/ioutil"
 	"reflect"
 	"regexp"
@@ -85,9 +86,23 @@ func (r *RefResolver) ResolveLocalRef(localRef, callerRef string) interface{} {
 		return localRef
 	}
 
+	valKind := reflect.TypeOf(val).Kind()
+
 	// replace the local value reference string with actual value
-	if reflect.TypeOf(val).Kind() == reflect.String {
-		valStr := val.(string)
+	if valKind == reflect.String || valKind == reflect.Map {
+		valStr := ""
+
+		if valKind == reflect.Map {
+			data, err := json.Marshal(val)
+			if err != nil {
+				zap.S().Errorf("failed to convert expression '%v', ref: '%v'", localAttr.Expr, localRef)
+				return localRef
+			}
+			valStr = string(data)
+		} else {
+			valStr = val.(string)
+		}
+
 		resolvedVal := strings.Replace(localRef, localExpr, valStr, 1)
 		if callerRef != "" && strings.Contains(resolvedVal, callerRef) {
 			zap.S().Debugf("resolved str local value ref: '%v', value: '%v'", localRef, resolvedVal)
