@@ -142,41 +142,3 @@ func TestIsValidTFPlanJSON(t *testing.T) {
 		})
 	}
 }
-
-func TestGetTFID(t *testing.T) {
-
-	table := []struct {
-		name  string
-		input string
-		want  string
-	}{
-		{
-			name:  "empty input",
-			input: "",
-			want:  "",
-		},
-		{
-			name:  "regular terraform id",
-			input: "x.y",
-			want:  "x.y",
-		},
-		{
-			name:  "long terraform id",
-			input: "x.y.z",
-			want:  "y.z",
-		},
-		{
-			name:  "extra long terraform id",
-			input: "w.x.y.z",
-			want:  "y.z",
-		},
-	}
-
-	for _, tt := range table {
-		got := getTFID(tt.input)
-		if got != tt.want {
-			t.Errorf("got: '%v', want: '%v'", got, tt.want)
-		}
-	}
-
-}
