@@ -18,6 +18,7 @@ package runtime
 
 import (
 	"fmt"
+	tfv15 "github.com/accurics/terrascan/pkg/iac-providers/terraform/v15"
 	"path/filepath"
 	"reflect"
 	"testing"
@@ -178,7 +179,49 @@ func TestExecute(t *testing.T) {
 
 	for _, tt := range table {
 		t.Run(tt.name, func(t *testing.T) {
-			_, gotErr := tt.executor.Execute()
+			_, gotErr := tt.executor.Execute(false)
+			if !reflect.DeepEqual(gotErr, tt.wantErr) {
+				t.Errorf("unexpected error; gotErr: '%v', wantErr: '%v'", gotErr, tt.wantErr)
+			}
+		})
+	}
+}
+
+func TestInitPolicyEngine(t *testing.T) {
+	table := []struct {
+		name     string
+		executor Executor
+		wantErr  error
+	}{
+		{
+			name: "invalid policy path",
+			executor: Executor{
+				filePath:    filepath.Join(testDataDir, "testfile"),
+				dirPath:     "",
+				policyTypes: []string{"aws"},
+				iacType:     "terraform",
+				iacVersion:  "v14",
+				policyPath:  []string{filepath.Join(testDataDir, "notthere")},
+			},
+			wantErr: fmt.Errorf("failed to initialize OPA policy engine"),
+		},
+		{
+			name: "invalid policy path",
+			executor: Executor{
+				filePath:    filepath.Join(testDataDir, "testfile"),
+				dirPath:     "",
+				policyTypes: []string{"aws"},
+				iacType:     "terraform",
+				iacVersion:  "v12",
+				policyPath:  []string{filepath.Join(testDataDir, "notthere")},
+			},
+			wantErr: fmt.Errorf("failed to initialize OPA policy engine"),
+		},
+	}
+
+	for _, tt := range table {
+		t.Run(tt.name, func(t *testing.T) {
+			gotErr := tt.executor.initPolicyEngines()
 			if !reflect.DeepEqual(gotErr, tt.wantErr) {
 				t.Errorf("unexpected error; gotErr: '%v', wantErr: '%v'", gotErr, tt.wantErr)
 			}
@@ -217,7 +260,7 @@ func TestInit(t *testing.T) {
 				policyPath:  []string{testPoliciesDir},
 			},
 			wantErr:         nil,
-			wantIacProvider: []iacProvider.IacProvider{&armv1.ARMV1{}, &cftv1.CFTV1{}, &helmv3.HelmV3{}, &k8sv1.K8sV1{}, &kustomizev3.KustomizeV3{}, &tfv14.TfV14{}},
+			wantIacProvider: []iacProvider.IacProvider{&armv1.ARMV1{}, &cftv1.CFTV1{}, &helmv3.HelmV3{}, &k8sv1.K8sV1{}, &kustomizev3.KustomizeV3{}, &tfv15.TfV15{}},
 			wantNotifiers:   []notifications.Notifier{},
 		},
 		{
@@ -228,7 +271,7 @@ func TestInit(t *testing.T) {
 				policyPath:  []string{testPoliciesDir},
 			},
 			wantErr:         nil,
-			wantIacProvider: []iacProvider.IacProvider{&tfv14.TfV14{}},
+			wantIacProvider: []iacProvider.IacProvider{&tfv15.TfV15{}},
 			wantNotifiers:   []notifications.Notifier{},
 		},
 		{
@@ -273,21 +316,6 @@ func TestInit(t *testing.T) {
 			wantErr:         config.ErrNotPresent,
 			wantIacProvider: []iacProvider.IacProvider{&tfv14.TfV14{}},
 		},
-		{
-			name: "invalid policy path",
-			executor: Executor{
-				filePath:    filepath.Join(testDataDir, "testfile"),
-				dirPath:     "",
-				policyTypes: []string{"aws"},
-				iacType:     "terraform",
-				iacVersion:  "v14",
-				policyPath:  []string{filepath.Join(testDataDir, "notthere")},
-			},
-			configFile:      filepath.Join(testDataDir, "webhook.toml"),
-			wantErr:         fmt.Errorf("failed to initialize OPA policy engine"),
-			wantIacProvider: []iacProvider.IacProvider{&tfv14.TfV14{}},
-			wantNotifiers:   []notifications.Notifier{&webhook.Webhook{}},
-		},
 		{
 			name: "config file with invalid category",
 			executor: Executor{
@@ -358,21 +386,6 @@ func TestInit(t *testing.T) {
 			wantErr:         config.ErrNotPresent,
 			wantIacProvider: []iacProvider.IacProvider{&tfv12.TfV12{}},
 		},
-		{
-			name: "invalid policy path",
-			executor: Executor{
-				filePath:    filepath.Join(testDataDir, "testfile"),
-				dirPath:     "",
-				policyTypes: []string{"aws"},
-				iacType:     "terraform",
-				iacVersion:  "v12",
-				policyPath:  []string{filepath.Join(testDataDir, "notthere")},
-			},
-			configFile:      filepath.Join(testDataDir, "webhook.toml"),
-			wantErr:         fmt.Errorf("failed to initialize OPA policy engine"),
-			wantIacProvider: []iacProvider.IacProvider{&tfv12.TfV12{}},
-			wantNotifiers:   []notifications.Notifier{&webhook.Webhook{}},
-		},
 	}
 
 	for _, tt := range table {
