@@ -21,6 +21,7 @@ import (
 	"github.com/accurics/terrascan/pkg/policy"
 	"github.com/accurics/terrascan/pkg/utils"
 	"github.com/accurics/terrascan/pkg/version"
+	"github.com/go-errors/errors"
 	"github.com/owenrumney/go-sarif/sarif"
 	"go.uber.org/zap"
 	"io"
@@ -38,6 +39,10 @@ func init() {
 
 // SarifWriter writes sarif formatted violation results report
 func SarifWriter(data interface{}, writer io.Writer) error {
+	return writeSarif(data, writer, false)
+}
+
+func writeSarif(data interface{}, writer io.Writer, forGithub bool) error {
 	outputData := data.(policy.EngineOutput)
 	report, err := sarif.New(sarif.Version210)
 	if err != nil {
@@ -46,7 +51,6 @@ func SarifWriter(data interface{}, writer io.Writer) error {
 
 	run := sarif.NewRun("terrascan", "https://github.com/accurics/terrascan")
 	run.Tool.Driver.WithVersion(version.GetNumeric())
-
 	// add a run to the report
 	report.AddRun(run)
 
@@ -55,7 +59,7 @@ func SarifWriter(data interface{}, writer io.Writer) error {
 		m["category"] = passedRule.Category
 		m["severity"] = passedRule.Severity
 
-		run.AddRule(string(passedRule.RuleID)).
+		run.AddRule(passedRule.RuleID).
 			WithDescription(passedRule.Description).WithName(passedRule.RuleName).WithProperties(m)
 	}
 
@@ -65,19 +69,24 @@ func SarifWriter(data interface{}, writer io.Writer) error {
 		m["category"] = violation.Category
 		m["severity"] = violation.Severity
 
-		rule := run.AddRule(string(violation.RuleID)).
+		rule := run.AddRule(violation.RuleID).
 			WithDescription(violation.Description).WithName(violation.RuleName).WithProperties(m)
 
-		absFilePath, err := getAbsoluteFilePath(outputData.Summary.ResourcePath, violation.File)
+		var artifactLocation *sarif.ArtifactLocation
 
-		if err != nil {
-			return err
+		if forGithub {
+			artifactLocation = sarif.NewSimpleArtifactLocation(violation.File).
+				WithUriBaseId(outputData.Summary.ResourcePath)
+		} else {
+			absFilePath, err := getAbsoluteFilePath(outputData.Summary.ResourcePath, violation.File)
+			if err != nil {
+				return errors.Errorf("unable to create absolute path, error: %v", err)
+			}
+			artifactLocation = sarif.NewSimpleArtifactLocation(fmt.Sprintf("file://%s", absFilePath))
 		}
 
-		location := sarif.NewLocation().
-			WithPhysicalLocation(sarif.NewPhysicalLocation().
-				WithArtifactLocation(sarif.NewSimpleArtifactLocation(fmt.Sprintf("file://%s", absFilePath))).
-				WithRegion(sarif.NewRegion().WithStartLine(violation.LineNumber)))
+		location := sarif.NewLocation().WithPhysicalLocation(sarif.NewPhysicalLocation().
+			WithArtifactLocation(artifactLocation).WithRegion(sarif.NewRegion().WithStartLine(violation.LineNumber)))
 
 		if len(violation.ResourceType) > 0 && len(violation.ResourceName) > 0 {
 			location.LogicalLocations = append(location.LogicalLocations, sarif.NewLogicalLocation().
